==> dxcr-vue-cesium-0.0.1.tgz: package/lib/datasource/kml/index.js <==
/**
 * vue-cesium - https://github.com/zouyaoji/vue-cesium
 * Vue 2.x components for CesiumJS.
 *
 * @package VueCesium
 * @author zouyaoji <370681295@qq.com>
 * @version 2.1.6
 * @license MIT
 * @homepage https://zouyaoji.top/vue-cesium
 * @copyright (c) 2018-2020, zouyaoji <370681295@qq.com>
 */
import _regeneratorRuntime from '@babel/runtime-corejs2/regenerator';
import mixinDatasource from '../../mixins/datasource/mixinDatasource';

var script = {
  name: 'vc-datasource-kml',
  mixins: [mixinDatasource],
  props: {
    data: {
      type: String | Object,
      required: true
    },
    options: {
      type: Object,
      default: function _default() {
        return {
          clampToGround: false
        };
      }
    }
  },
  methods: {
    createCesiumObject: function createCesiumObject() {
      var $props, transformProps, viewer, options;
      return _regeneratorRuntime.async(function createCesiumObject$(_context) {
        while (1) {
          switch (_context.prev = _context.next) {
            case 0:
              $props = this.$props, transformProps = this.transformProps, viewer = this.viewer;
              options = transformProps($props);

              if (!options.camera) {
                options.camera = viewer.camera;
              }

              if (!options.canvas) {
                options.canvas = viewer.canvas;
              }

              return _context.abrupt("return", Cesium.KmlDataSource.load(options.data, options.options));

            case 5:
            case "end":
              return _context.stop();
          }
        }
      }, null, this);
    }
  }
};

/* script */
var __vue_script__ = script;
/* template */

/* style */

var __vue_inject_styles__ = undefined;
/* scoped */

var __vue_scope_id__ = undefined;
/* functional template */

var __vue_is_functional_template__ = undefined;
/* component normalizer */

function __vue_normalize__(template, style, script, scope, functional, moduleIdentifier, createInjector, createInjectorSSR) {
  var component = (typeof script === 'function' ? script.options : script) || {}; // For security concerns, we use only base name in production mode.

  component.__file = "KmlDataSource.vue";

  if (!component.render) {
    component.render = template.render;
    component.staticRenderFns = template.staticRenderFns;
    component._compiled = true;
    if (functional) component.functional = true;
  }

  component._scopeId = scope;

  return component;
}
/* style inject */

/* style inject SSR */


var KmlDataSource = __vue_normalize__({}, __vue_inject_styles__, __vue_script__, __vue_scope_id__, __vue_is_functional_template__);

function plugin(Vue) {

  if (plugin.installed) {
    return;
  }

  plugin.installed = true;
  Vue.component(KmlDataSource.name, KmlDataSource);
}

export default plugin;
export { KmlDataSource, plugin as install };

==> dxcr-vue-cesium-0.0.2.tgz: package/lib/datasource/kml/index.js <==
/**
 * vue-cesium - https://github.com/zouyaoji/vue-cesium
 * Vue 2.x components for CesiumJS.
 *
 * @package VueCesium
 * @author zouyaoji <370681295@qq.com>
 * @version 2.2.0
 * @license MIT
 * @homepage https://zouyaoji.top/vue-cesium
 * @copyright (c) 2018-2021, zouyaoji <370681295@qq.com>
 */
import _regeneratorRuntime from '@babel/runtime-corejs2/regenerator';
import { data, options } from '../../mixins/mixinProps';
import mixinDatasource from '../../mixins/datasource/mixinDatasource';

var script = {
  name: 'vc-datasource-kml',
  mixins: [data, options, mixinDatasource],
  methods: {
    createCesiumObject: function createCesiumObject() {
      var $props, transformProps, viewer, options;
      return _regeneratorRuntime.async(function createCesiumObject$(_context) {
        while (1) {
          switch (_context.prev = _context.next) {
            case 0:
              $props = this.$props, transformProps = this.transformProps, viewer = this.viewer;
              options = transformProps($props);
              options.options = options.options || {};

              if (!options.options.camera) {
                options.options.camera = viewer.camera;
              }

              if (!options.options.canvas) {
                options.options.canvas = viewer.canvas;
              }

              return _context.abrupt("return", Cesium.KmlDataSource.load(options.data, options.options));

            case 6:
            case "end":
              return _context.stop();
          }
        }
      }, null, this);
    }
  }
};

/* script */
var __vue_script__ = script;
/* template */

/* style */

var __vue_inject_styles__ = undefined;
/* scoped */

var __vue_scope_id__ = undefined;
/* functional template */

var __vue_is_functional_template__ = undefined;
/* component normalizer */

function __vue_normalize__(template, style, script, scope, functional, moduleIdentifier, createInjector, createInjectorSSR) {
  var component = (typeof script === 'function' ? script.options : script) || {}; // For security concerns, we use only base name in production mode.

  component.__file = "KmlDataSource.vue";

  if (!component.render) {
    component.render = template.render;
    component.staticRenderFns = template.staticRenderFns;
    component._compiled = true;
    if (functional) component.functional = true;
  }

  component._scopeId = scope;

  return component;
}
/* style inject */

/* style inject SSR */


var KmlDataSource = __vue_normalize__({}, __vue_inject_styles__, __vue_script__, __vue_scope_id__, __vue_is_functional_template__);

function plugin(Vue) {

  if (plugin.installed) {
    return;
  }

  plugin.installed = true;
  Vue.component(KmlDataSource.name, KmlDataSource);
}

export default plugin;
export { KmlDataSource, plugin as install };
